@@ -18,9 +18,7 @@ gchar * pluma_file_browser_utils_uri_basename             (gchar const * uri);
 gboolean pluma_file_browser_utils_confirmation_dialog     (PlumaWindow * window,
                                                            GtkMessageType type,
                                                            gchar const *message,
-		                                           gchar const *secondary, 
-		                                           gchar const * button_stock, 
-		                                           gchar const * button_label);
+                                                           gchar const *secondary);
 
 #endif /* __PLUMA_FILE_BROWSER_UTILS_H__ */
 
