@@ -2,7 +2,7 @@
  * pluma-taglist-plugin-panel.h
  * This file is part of pluma
  *
- * Copyright (C) 2005 - Paolo Maggi 
+ * Copyright (C) 2005 - Paolo Maggi
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,14 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
- 
+
 /*
- * Modified by the pluma Team, 2005. See the AUTHORS file for a 
- * list of people on the pluma Team.  
- * See the ChangeLog files for a list of changes. 
+ * Modified by the pluma Team, 2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
+ * See the ChangeLog files for a list of changes.
  *
  * $Id$
  */
@@ -56,13 +56,9 @@ typedef struct _PlumaTaglistPluginPanelPrivate PlumaTaglistPluginPanelPrivate;
  */
 typedef struct _PlumaTaglistPluginPanel PlumaTaglistPluginPanel;
 
-struct _PlumaTaglistPluginPanel 
+struct _PlumaTaglistPluginPanel
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkBox vbox;
-#else
-	GtkVBox vbox;
-#endif
 
 	/*< private > */
 	PlumaTaglistPluginPanelPrivate *priv;
@@ -73,20 +69,16 @@ struct _PlumaTaglistPluginPanel
  */
 typedef struct _PlumaTaglistPluginPanelClass PlumaTaglistPluginPanelClass;
 
-struct _PlumaTaglistPluginPanelClass 
+struct _PlumaTaglistPluginPanelClass
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkBoxClass parent_class;
-#else
-	GtkVBoxClass parent_class;
-#endif
 };
 
 /*
  * Public methods
  */
-GType		 pluma_taglist_plugin_panel_register_type	(GTypeModule *module);
-							
+void		 _pluma_taglist_plugin_panel_register_type	(GTypeModule *module);
+
 GType 		 pluma_taglist_plugin_panel_get_type		(void) G_GNUC_CONST;
 
 GtkWidget	*pluma_taglist_plugin_panel_new 		(PlumaWindow *window,
