@@ -120,6 +120,11 @@ parse_tag_group (TagGroup *tg, const gchar* fn, xmlDocPtr doc,
 
 	while (cur != NULL)
 	{
+		if (xmlStrcmp (cur->name, (const xmlChar *) "comment") == 0)
+		{
+			cur = cur->next;
+		}
+
 		if ((xmlStrcmp (cur->name, (const xmlChar *) "Tag")) || (cur->ns != ns))
 		{
 			g_warning ("The tag list file '%s' is of the wrong type, "
@@ -134,7 +139,7 @@ parse_tag_group (TagGroup *tg, const gchar* fn, xmlDocPtr doc,
 			tag = g_new0 (Tag, 1);
 
 			/* Get Tag name */
-			tag->name = xmlGetProp (cur, (const xmlChar *) "name");
+			tag->name = (xmlChar*)gettext((const char*)xmlGetProp (cur, (const xmlChar *) "name"));
 
 			if (tag->name == NULL)
 			{
@@ -190,7 +195,7 @@ get_tag_group (const gchar* filename, xmlDocPtr doc,
 	tag_group = g_new0 (TagGroup, 1);
 
 	/* Get TagGroup name */
-	tag_group->name = xmlGetProp (cur, (const xmlChar *) "name");
+	tag_group->name = (xmlChar*)gettext((const char*)xmlGetProp (cur, (const xmlChar *) "name"));
 
 	sort_str = xmlGetProp (cur, (const xmlChar *) "sort");
 
