@@ -2,7 +2,7 @@
  * pluma-documents-panel.c
  * This file is part of pluma
  *
- * Copyright (C) 2005 - Paolo Maggi 
+ * Copyright (C) 2005 - Paolo Maggi
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,14 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
- 
+
 /*
- * Modified by the pluma Team, 2005. See the AUTHORS file for a 
- * list of people on the pluma Team.  
- * See the ChangeLog files for a list of changes. 
+ * Modified by the pluma Team, 2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
+ * See the ChangeLog files for a list of changes.
  *
  * $Id$
  */
@@ -38,10 +38,6 @@
 
 #include <glib/gi18n.h>
 
-#define PLUMA_DOCUMENTS_PANEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
-						  PLUMA_TYPE_DOCUMENTS_PANEL,            \
-						  PlumaDocumentsPanelPrivate))
-
 struct _PlumaDocumentsPanelPrivate
 {
 	PlumaWindow  *window;
@@ -53,7 +49,7 @@ struct _PlumaDocumentsPanelPrivate
 	guint         is_reodering : 1;
 };
 
-G_DEFINE_TYPE(PlumaDocumentsPanel, pluma_documents_panel, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (PlumaDocumentsPanel, pluma_documents_panel, GTK_TYPE_BOX)
 
 enum
 {
@@ -98,7 +94,7 @@ tab_get_name (PlumaTab *tab)
 		}
 		else
 		{
-			tab_name = g_markup_printf_escaped ("<i>%s</i>", 
+			tab_name = g_markup_printf_escaped ("<i>%s</i>",
 							    docname);
 		}
 	}
@@ -144,7 +140,7 @@ static void
 window_active_tab_changed (PlumaWindow         *window,
 			   PlumaTab            *tab,
 			   PlumaDocumentsPanel *panel)
-{	
+{
 	g_return_if_fail (tab != NULL);
 
 	if (!_pluma_window_is_removing_tabs (window))
@@ -177,7 +173,7 @@ refresh_list (PlumaDocumentsPanel *panel)
 	PlumaTab *active_tab;
 
 	/* g_debug ("refresh_list"); */
-	
+
 	list_store = GTK_LIST_STORE (panel->priv->model);
 
 	gtk_list_store_clear (list_store);
@@ -190,9 +186,9 @@ refresh_list (PlumaDocumentsPanel *panel)
 	l = tabs;
 
 	panel->priv->adding_tab = TRUE;
-	
+
 	while (l != NULL)
-	{	
+	{
 		GdkPixbuf *pixbuf;
 		gchar *name;
 		GtkTreeIter iter;
@@ -225,7 +221,7 @@ refresh_list (PlumaDocumentsPanel *panel)
 
 		l = g_list_next (l);
 	}
-	
+
 	panel->priv->adding_tab = FALSE;
 
 	g_list_free (tabs);
@@ -295,8 +291,8 @@ window_tab_added (PlumaWindow         *window,
 	get_iter_from_tab (panel, tab, &sibling);
 
 	panel->priv->adding_tab = TRUE;
-	
-	if (gtk_list_store_iter_is_valid (GTK_LIST_STORE (panel->priv->model), 
+
+	if (gtk_list_store_iter_is_valid (GTK_LIST_STORE (panel->priv->model),
 					  &sibling))
 	{
 		gtk_list_store_insert_after (GTK_LIST_STORE (panel->priv->model),
@@ -307,7 +303,7 @@ window_tab_added (PlumaWindow         *window,
 	{
 		PlumaTab *active_tab;
 
-		gtk_list_store_append (GTK_LIST_STORE (panel->priv->model), 
+		gtk_list_store_append (GTK_LIST_STORE (panel->priv->model),
 				       &iter);
 
 		active_tab = pluma_window_get_active_tab (panel->priv->window);
@@ -435,8 +431,8 @@ pluma_documents_panel_get_property (GObject    *object,
 	switch (prop_id)
 	{
 		case PROP_WINDOW:
-			g_value_set_object (value,
-					    PLUMA_DOCUMENTS_PANEL_GET_PRIVATE (panel)->window);
+			panel->priv = pluma_documents_panel_get_instance_private (panel);
+			g_value_set_object (value, panel->priv->window);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -448,7 +444,7 @@ static void
 pluma_documents_panel_finalize (GObject *object)
 {
 	/* PlumaDocumentsPanel *tab = PLUMA_DOCUMENTS_PANEL (object); */
-	
+
 	/* TODO: disconnect signal with window */
 
 	G_OBJECT_CLASS (pluma_documents_panel_parent_class)->finalize (object);
@@ -468,7 +464,7 @@ pluma_documents_panel_dispose (GObject *object)
 	G_OBJECT_CLASS (pluma_documents_panel_parent_class)->dispose (object);
 }
 
-static void 
+static void
 pluma_documents_panel_class_init (PlumaDocumentsPanelClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
@@ -487,8 +483,6 @@ pluma_documents_panel_class_init (PlumaDocumentsPanelClass *klass)
 							      G_PARAM_READWRITE |
 							      G_PARAM_CONSTRUCT_ONLY |
 							      G_PARAM_STATIC_STRINGS));
-
-	g_type_class_add_private (object_class, sizeof (PlumaDocumentsPanelPrivate));
 }
 
 static gboolean
@@ -533,7 +527,7 @@ panel_button_press_event (GtkTreeView         *treeview,
 							   NULL,
 							   NULL,
 							   NULL))
-			{				
+			{
 
 				gtk_tree_view_set_cursor (treeview,
 							  path,
@@ -632,19 +626,19 @@ treeview_row_inserted (GtkTreeModel        *tree_model,
 	GtkWidget *nb;
 	gint old_position;
 	gint new_position;
-	
+
 	if (panel->priv->adding_tab)
 		return;
-		
+
 	tab = pluma_window_get_active_tab (panel->priv->window);
 	g_return_if_fail (tab != NULL);
 
 	panel->priv->is_reodering = TRUE;
-	
+
 	indeces = gtk_tree_path_get_indices (path);
-	
+
 	/* g_debug ("New Index: %d (path: %s)", indeces[0], gtk_tree_path_to_string (path));*/
-	
+
 	nb = _pluma_window_get_notebook (panel->priv->window);
 
 	new_position = indeces[0];
@@ -652,7 +646,7 @@ treeview_row_inserted (GtkTreeModel        *tree_model,
 				    	      GTK_WIDGET (tab));
 	if (new_position > old_position)
 		new_position = MAX (0, new_position - 1);
-		
+
 	pluma_notebook_reorder_tab (PLUMA_NOTEBOOK (nb),
 				    tab,
 				    new_position);
@@ -668,18 +662,18 @@ pluma_documents_panel_init (PlumaDocumentsPanel *panel)
 	GtkCellRenderer 	*cell;
 	GtkTreeSelection 	*selection;
 
-	panel->priv = PLUMA_DOCUMENTS_PANEL_GET_PRIVATE (panel);
-	
+	panel->priv = pluma_documents_panel_get_instance_private (panel);
+
 	panel->priv->adding_tab = FALSE;
 	panel->priv->is_reodering = FALSE;
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (panel),
 	                                GTK_ORIENTATION_VERTICAL);
-	
+
 	/* Create the scrolled window */
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	g_return_if_fail (sw != NULL);
-	
+
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
@@ -687,7 +681,7 @@ pluma_documents_panel_init (PlumaDocumentsPanel *panel)
                                              GTK_SHADOW_IN);
 	gtk_widget_show (sw);
 	gtk_box_pack_start (GTK_BOX (panel), sw, TRUE, TRUE, 0);
-	
+
 	/* Create the empty model */
 	panel->priv->model = GTK_TREE_MODEL (gtk_list_store_new (N_COLUMNS,
 								 GDK_TYPE_PIXBUF,
@@ -704,7 +698,7 @@ pluma_documents_panel_init (PlumaDocumentsPanel *panel)
 	g_object_set (panel->priv->treeview, "has-tooltip", TRUE, NULL);
 
 	gtk_widget_show (panel->priv->treeview);
-	
+
 	column = gtk_tree_view_column_new ();
 	gtk_tree_view_column_set_title (column, _("Documents"));
 
@@ -717,12 +711,12 @@ pluma_documents_panel_init (PlumaDocumentsPanel *panel)
 
 	gtk_tree_view_append_column (GTK_TREE_VIEW (panel->priv->treeview),
 				     column);
-				     
+
 	selection = gtk_tree_view_get_selection (
 			GTK_TREE_VIEW (panel->priv->treeview));
 
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
-	
+
 	g_signal_connect (panel->priv->treeview,
 			  "cursor_changed",
 			  G_CALLBACK (treeview_cursor_changed),
